# 学工平台出校申请

本项目为使用命令行提交哈尔滨工业大学[学工平台](https://xg.hit.edu.cn/)[出入校申请](https://xg.hit.edu.cn/zhxy-xgzs/xg_mobile/xsCxsq)的工具。实现了按照配置文件登录，申请出校的功能。

## 如何使用

1. `pip install cxsq`
2. 按照下面模板填写账号密码等信息
3. 运行 `cxsq -c config_file [-d date1 date2 ... | -T | -t]`

## 出校日期参数

参数可多选，添加多个日期

- `-d date ...` 申请指定日期的临时出校，`date` 格式为 `yyyyMMdd`
- `-t` 申请今日出校
- `-T` 申请明日出校

## 配置文件模板

```yaml
# 统一身份认证账号
username: "1200000000"
# 统一身份认证密码
password: "PASSWORD"
# 出校理由, 可选, 默认为空格
reasons: ["吃饭", "睡觉", "打豆豆"]
```

## 开源许可证

[AGPL-3.0](./LICENSE)

简单来说，建议您做到以下几点：

- 任何基于或与本项目有间接接触的项目均使用 AGPL-3.0 协议
- 当你使用本项目或对其修改时，如果你所服务的对象向您索要源代码，请不要拒绝
- 请不要将本项目用于商业用途

## 免责声明

本项目仅为方便通过命令行进行每日上报的工具。按照 [LICENSE](./LICENSE)，开发者不对本工具的使用负责。
